# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

import requests, urllib3, ssl

class CustomHttpAdapter(requests.adapters.HTTPAdapter):
    def __init__(self, ssl_context=None, **kwargs):
        self.ssl_context = ssl_context
        super().__init__(**kwargs)

    def init_poolmanager(self, connections, maxsize, block=False):
        self.poolmanager = urllib3.poolmanager.PoolManager(
            num_pools=connections, maxsize=maxsize,
            block=block, ssl_context=self.ssl_context
        )

def legacy_session():
    ctx         = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
    ctx.options |= 0x4  # OP_LEGACY_SERVER_CONNECT

    session = requests.session()
    session.mount("https://", CustomHttpAdapter(ctx))
    return session